@@ -40,7 +40,7 @@ class Player(Base):
     @classmethod
     def load(cls, *ids):
         """
-        Load dictioary of players
+        Load dictionary of players
         """
         players = database.get_player(list(ids))
         return {
@@ -96,7 +96,11 @@ class Player(Base):
         return self._rating_to_stars(self.defense_rating)
 
     def get_vibe(self, day):
-        return 0.5 * ((self.pressurization + self.cinnamon) * math.cos((math.pi * day) / (5 * self.buoyancy + 3)) -
+        """
+        Day is 1-indexed
+        """
+        return 0.5 * ((self.pressurization + self.cinnamon) *
+                      math.sin(math.pi * (2 / (6 + round(10 * self.buoyancy)) * (day - 1) + 0.5)) -
                       self.pressurization + self.cinnamon)
 
     @property
@@ -428,6 +432,10 @@ class League(Base):
     def load(cls):
         return cls(database.get_league())
 
+    @classmethod
+    def load_by_id(cls, id_):
+        return cls(database.get_league(id_))
+
     @property
     def subleagues(self):
         if self._subleagues:
@@ -583,7 +591,7 @@ class BlessingResult(Base):
         return self.bonus_id
 
 
-class OffseasonResult(Base):
+class ElectionResult(Base):
 
     @classmethod
     def load_by_season(cls, season):
@@ -624,5 +632,202 @@ class OffseasonResult(Base):
         self._decree_results = None
         self._decree_results_ids = value
 
+OffseasonResult = ElectionResult
 
-# TODO offseason setup and playoff stuff
+
+class Playoff(Base):
+
+    @classmethod
+    def load_by_season(cls, season):
+        playoff = database.get_playoff_details(season)
+        return cls(playoff)
+
+    @property
+    def rounds(self):
+        if self._rounds:
+            return self._rounds
+        self._rounds = [PlayoffRound.load(id_) for id_ in self._rounds_ids]
+        return self._rounds
+
+    @rounds.setter
+    def rounds(self, value):
+        self._rounds = None
+        self._rounds_ids = value
+
+    def get_round_by_number(self, round_number):
+        """
+        Get games from a specific round of playoffs
+        Round number is 1-indexed
+        """
+        num = round_number - 1
+        if num >= len(self._rounds_ids) or num < 0:
+            return None
+        return self.rounds[num]
+
+    @property
+    def winner(self):
+        if self._winner:
+            return self._winner
+        self._winner = Team.load(self._winner_id)
+        return self._winner
+
+    @winner.setter
+    def winner(self, value):
+        self._winner = None
+        self._winner_id = value
+
+
+class PlayoffRound(Base):
+
+    @classmethod
+    def load(cls, id_):
+        round_ = database.get_playoff_round(id_)
+        return cls(round_)
+
+    @property
+    def games(self):
+        """
+        Get all games
+        Lots of endpoint calls, not recommended
+        """
+        if all(self._games):
+            return self._games
+        for day, games in enumerate(self._games_ids):
+            if self._games[day]:
+                continue
+            self._games[day] = [Game.load_by_id(id_) for id_ in games if id_ != "none"]
+        return self._games
+
+    @games.setter
+    def games(self, value):
+        self._games = [None] * len(value)
+        self._games_ids = value
+
+    def get_games_by_number(self, game_number):
+        """
+        Get games by game number in series (IE: Game 1 of 5)
+        Game number is 1-indexed
+        """
+        num = game_number - 1
+        if num >= len(self._games_ids) or num < 0:
+            return []
+        if self._games[num]:
+            return self._games[num]
+        self._games[num] = [Game.load_by_id(id_) for id_ in self._games_ids[num] if id_ != "none"]
+        return self._games[num]
+
+    @property
+    def matchups(self):
+        if self._matchups:
+            return self._matchups
+        matchups = PlayoffMatchup.load(*self._matchups_ids)
+        self._matchups = [matchups.get(id_) for id_ in self._matchups_ids]
+        return self._matchups
+
+    @matchups.setter
+    def matchups(self, value):
+        self._matchups = None
+        self._matchups_ids = value
+
+    @property
+    def winners(self):
+        if self._winners:
+            return self._winners
+        self._winners = [Team.load(x) for x in self._winners_ids]
+        return self._winners
+
+    @winners.setter
+    def winners(self, value):
+        self._winners = None
+        self._winners_ids = value
+
+
+class PlayoffMatchup(Base):
+
+    @classmethod
+    def load(cls, *ids_):
+        matchups = database.get_playoff_matchups(list(ids_))
+        return {
+            id_: cls(matchup) for (id_, matchup) in matchups.items()
+        }
+
+    @classmethod
+    def load_one(cls, id_):
+        return cls.load(id_).get(id_)
+
+    @property
+    def away_team(self):
+        if self._away_team:
+            return self._away_team
+        self._away_team = Team.load(self._away_team_id)
+        return self._away_team
+
+    @away_team.setter
+    def away_team(self, value):
+        self._away_team = None
+        self._away_team_id = value
+
+    @property
+    def home_team(self):
+        if self._home_team:
+            return self._home_team
+        self._home_team = Team.load(self._home_team_id)
+        return self._home_team
+
+    @home_team.setter
+    def home_team(self, value):
+        self._home_team = None
+        self._home_team_id = value
+
+
+class Election(Base):
+
+    @classmethod
+    def load(cls):
+        offseason = database.get_offseason_election_details()
+        return cls(offseason)
+
+OffseasonSetup = Election
+
+
+class Standings(Base):
+
+    @classmethod
+    def load(cls, id_):
+        standings = database.get_standings(id_)
+        return cls(standings)
+
+    def get_standings_by_team(self, id_):
+        return {"wins": self.wins.get(id_, None), "losses": self.losses.get(id_, None)}
+
+
+class Season(Base):
+
+    @classmethod
+    def load(cls, season_number):
+        season = database.get_season(season_number)
+        return cls(season)
+
+    @property
+    def league(self):
+        if self._league:
+            return self._league
+        self._league = League.load_by_id(self._league_id)
+        return self._league
+
+    @league.setter
+    def league(self, value):
+        self._league = None
+        self._league_id = value
+
+    @property
+    def standings(self):
+        if self._standings:
+            return self._standings
+        self._standings = Standings.load(self._standings_id)
+        return self._standings
+
+    @standings.setter
+    def standings(self, value):
+        self._standings = None
+        self._standings_id = value
